@@ -16,7 +16,7 @@ from pre_commit.output import get_hook_message
 from pre_commit.repository import all_hooks
 from pre_commit.repository import install_hook_envs
 from pre_commit.staged_files_only import staged_files_only
-from pre_commit.util import cmd_output
+from pre_commit.util import cmd_output_b
 from pre_commit.util import noop_context
 
 
@@ -34,6 +34,12 @@ def filter_by_include_exclude(names, include, exclude):
 
 class Classifier(object):
     def __init__(self, filenames):
+        # on windows we normalize all filenames to use forward slashes
+        # this makes it easier to filter using the `files:` regex
+        # this also makes improperly quoted shell-based hooks work better
+        # see #1173
+        if os.altsep == '/' and os.sep == '\\':
+            filenames = (f.replace(os.sep, os.altsep) for f in filenames)
         self.filenames = [f for f in filenames if os.path.lexists(f)]
         self._types_cache = {}
 
@@ -73,7 +79,7 @@ SKIPPED = 'Skipped'
 NO_FILES = '(no files to check)'
 
 
-def _run_single_hook(classifier, hook, args, skips, cols):
+def _run_single_hook(classifier, hook, args, skips, cols, use_color):
     filenames = classifier.filenames_for_hook(hook)
 
     if hook.language == 'pcre':
@@ -117,15 +123,10 @@ def _run_single_hook(classifier, hook, args, skips, cols):
     )
     sys.stdout.flush()
 
-    diff_before = cmd_output(
-        'git', 'diff', '--no-ext-diff', retcode=None, encoding=None,
-    )
-    retcode, stdout, stderr = hook.run(
-        tuple(filenames) if hook.pass_filenames else (),
-    )
-    diff_after = cmd_output(
-        'git', 'diff', '--no-ext-diff', retcode=None, encoding=None,
-    )
+    diff_before = cmd_output_b('git', 'diff', '--no-ext-diff', retcode=None)
+    filenames = tuple(filenames) if hook.pass_filenames else ()
+    retcode, out = hook.run(filenames, use_color)
+    diff_after = cmd_output_b('git', 'diff', '--no-ext-diff', retcode=None)
 
     file_modifications = diff_before != diff_after
 
@@ -145,7 +146,7 @@ def _run_single_hook(classifier, hook, args, skips, cols):
     output.write_line(color.format_color(pass_fail, print_color, args.color))
 
     if (
-            (stdout or stderr or file_modifications) and
+            (out or file_modifications) and
             (retcode or args.verbose or hook.verbose)
     ):
         output.write_line('hookid: {}\n'.format(hook.id))
@@ -154,15 +155,13 @@ def _run_single_hook(classifier, hook, args, skips, cols):
         if file_modifications:
             output.write('Files were modified by this hook.')
 
-            if stdout or stderr:
+            if out:
                 output.write_line(' Additional output:')
 
             output.write_line()
 
-        for out in (stdout, stderr):
-            assert type(out) is bytes, type(out)
-            if out.strip():
-                output.write_line(out.strip(), logfile_name=hook.log_file)
+        if out.strip():
+            output.write_line(out.strip(), logfile_name=hook.log_file)
         output.write_line()
 
     return retcode
@@ -211,7 +210,9 @@ def _run_hooks(config, hooks, args, environ):
     classifier = Classifier(filenames)
     retval = 0
     for hook in hooks:
-        retval |= _run_single_hook(classifier, hook, args, skips, cols)
+        retval |= _run_single_hook(
+            classifier, hook, args, skips, cols, args.color,
+        )
         if retval and config['fail_fast']:
             break
     if retval and args.show_diff_on_failure and git.has_diff():
@@ -235,12 +236,12 @@ def _run_hooks(config, hooks, args, environ):
 
 
 def _has_unmerged_paths():
-    _, stdout, _ = cmd_output('git', 'ls-files', '--unmerged')
+    _, stdout, _ = cmd_output_b('git', 'ls-files', '--unmerged')
     return bool(stdout.strip())
 
 
 def _has_unstaged_config(config_file):
-    retcode, _, _ = cmd_output(
+    retcode, _, _ = cmd_output_b(
         'git', 'diff', '--no-ext-diff', '--exit-code', config_file,
         retcode=None,
     )
